<!--
<p align="center">
  <img src="https://github.com/hrshdhgd/onto-crawler/raw/main/docs/source/logo.png" height="150">
</p>
-->

Crawl github for ontology specific issues.

## Getting Started

[Read the docs](https://hrshdhgd.github.io/onto-crawler/index.html)

<!-- ## Installation -->

<!-- Uncomment this section after first release
The most recent release can be installed from
[PyPI](https://pypi.org/project/onto_crawler/) with:

```bash
$ pip install onto-crawler
```
-->

<!-- The most recent code and data can be installed directly from GitHub with:

```bash
$ pip install git+https://github.com/hrshdhgd/onto-crawler.git
``` -->

<!-- ## Contributing

Contributions, whether filing an issue, making a pull request, or forking, are appreciated. See
[CONTRIBUTING.md](https://github.com/hrshdhgd/onto-crawler/blob/master/.github/CONTRIBUTING.md) for more information on getting involved. -->



### License

The code in this package is licensed under the MIT License.
